@@ -2,14 +2,15 @@
 import sys
 sys.path.append('.')
 
-from fixtures import reset_textstore, muchdata, teststore
+from fixtures import reset_textstore, muchdata, _teststore
+from tiddlyweb.model.bag import Bag
 from tiddlyweb.model.tiddler import Tiddler
 
 name = u'boom\u00BB\u00BBboom'
 
 def setup_module(module):
     reset_textstore()
-    module.store = teststore()
+    module.store = _teststore()
     muchdata(store)
 
 def test_simple_search():
@@ -20,7 +21,11 @@ def test_simple_search():
     assert tiddlers[0].text is None
 
 def test_unicode_search():
-    tiddler = Tiddler(name, bag='bag0')
+
+    bag = Bag('bagfoo')
+    store.put(bag)
+
+    tiddler = Tiddler(name, bag='bagfoo')
     tiddler.text = name
 
     store.put(tiddler)
